@@ -24,6 +24,9 @@ pub mod config;
 pub mod embed;
 /// Error handling.
 pub mod error;
+/// GitHub client.
+#[cfg(feature = "github")]
+pub mod github;
 /// Common release type.
 pub mod release;
 #[cfg(feature = "repo")]
@@ -37,3 +40,7 @@ extern crate log;
 
 /// Default configuration file.
 pub const DEFAULT_CONFIG: &str = "cliff.toml";
+/// Default output file.
+pub const DEFAULT_OUTPUT: &str = "CHANGELOG.md";
+/// Default ignore file.
+pub const IGNORE_FILE: &str = ".cliffignore";
